Crate tattoy_wezterm_escape_parser

Crate tattoy_wezterm_escape_parser 

This module provides the ability to parse escape sequences and attach semantic meaning to them. It can also encode the semantic values as escape sequences. It provides encoding and decoding functionality only; it does not provide terminal emulation facilities itself.

Re-exports

pub use self::apc::KittyImage;
pub use self::csi::CSI;
pub use self::error::Error;
pub use self::error::Result;
pub use self::esc::Esc;
pub use self::esc::EscCode;
pub use self::osc::OperatingSystemCommand;

Modules

apc
color
csi
error
esc
hyperlink
osc
parser
tmux_cc

Macros

bail
ensure
format_err

Structs

EnterDeviceControlMode
OneBased
A helper type to avoid accidentally tripping over problems with 1-based values in escape sequences.
ShortDeviceControl
A fully parsed DCS sequence. The parser emits these for byte/intermediate sequences that are known to be relatively short and self contained (eg: DECRQSS) as opposed to larger ones like Sixel (which is parsed separately), or long lived terminal modes such as the TMUX CC protocol.
Sixel
See https://vt100.net/docs/vt3xx-gp/chapter14.html

Enums

Action
ControlCode
C0 or C1 control codes
DeviceControlMode
SixelData

Type Aliases

SixelValue
A decoded 6-bit sixel value. Each sixel represents a six-pixel tall bitmap where the least significant bit is the topmost bit.